/*******************************************************
 *
 *  File: boot2nd_if.h
 *
 *  Author: Peter van Sebille (peter@yipton.net)
 *
 *  (c) Copyright 2001, Peter van Sebille
 *  All Rights Reserved
 *
 *******************************************************/

#ifndef __BOOT2ND_IF_H
#define __BOOT2ND_IF_H

/****************************************
 *
 * Interface file for BOOT2ND
 *
 ****************************************/



/***************************************
 *
 * preprocessor stuff only here
 *
 ***************************************/


#define SECTION_BOOT2ND_PAGES		0
#define SECTION_KERNEL_PAGES		1
#define SECTION_INITRD_PAGES		2

/*
 *   0: Free page allocated by boot1st    (used for stack) We depend on this being the first entry
 *   1: Boot1st paramater block
 *   2: Kernel boot string
 *   3: Free page alloacted by Arlo    (used to swap pages)
 *   4: First Boot2nd image            --v
 *   5: ...
 *    : 0                              --^ boot2nd section (section 0)
 *    : First kernel image             --v
 *    : ....
 *    : 0                              --^ kernel image section (section 1)
 *    : First initrd image             --v
 *    : ....
 *    : 0                              --^ initrd section (section 2)
 *    : -1								<-- depend on last entry being -1
 */
#define PAGE_NO_FREE_PAGE		0
#define PAGE_NO_BOOT1ST_PARAM	1
#define PAGE_NO_BOOT_PARAM		2
#define PAGE_NO_STACK			3
#define PAGE_NO_BOOT2ND			4

#define PAGE_SIZE				4096



/***************************************
 *
 * C/C++ stuff here
 *
 ***************************************/

#ifndef __ASM_ONLY__

/*
 * Interface with the Kernel. We put the PAGE with the kernel pramaters
 * 128KB in front of where the kernel is relocated to
 */
#define KERNEL_PARAM_DST(kernel_dst) (((unsigned*)(kernel_dst)) - ((128 * 1024) >> 2))

/*
 * This struct is passed in from the 1st stage boot loader (boot1st) in the page PAGE_NO_BOOT1ST_PARAM
 */
typedef struct _boot1st_param
{
	unsigned*	kernel_reloc_dst;
	unsigned*	initrd_reloc_dst;
	int			arm_arch_no;
	unsigned*	video_base;
	unsigned	video_width;
	unsigned	video_height;
	unsigned	video_bpp;
	unsigned	video_fg_colour;
	unsigned	video_bg_colour;
} boot1st_param_t;

#endif			/* __ASM_ONLY__ */


#endif			/* __BOOT2ND_IF_H */

